# coding: utf-8

"""
    Middleware

    Knowledge Graph data management.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from wordlift_client.models.longtail_response import LongtailResponse
from wordlift_client.models.rank_entities import RankEntities

from wordlift_client.api_client import ApiClient, RequestSerialized
from wordlift_client.api_response import ApiResponse
from wordlift_client.rest import RESTResponseType


class LongTailsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def get2(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LongtailResponse:
        """Get entities

        Query for long tail opportunities and receive entities.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LongtailResponse",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get2_with_http_info(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LongtailResponse]:
        """Get entities

        Query for long tail opportunities and receive entities.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LongtailResponse",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get2_without_preload_content(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get entities

        Query for long tail opportunities and receive entities.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LongtailResponse",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get2_serialize(
        self,
        q,
        ln,
        lc,
        sd,
        sc,
        d,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if ln is not None:
            
            _query_params.append(('ln', ln))
            
        if lc is not None:
            
            _query_params.append(('lc', lc))
            
        if sd is not None:
            
            _query_params.append(('sd', sd))
            
        if sc is not None:
            
            _query_params.append(('sc', sc))
            
        if d is not None:
            
            _query_params.append(('d', d))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/longtail',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def get3(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        hk: Annotated[StrictStr, Field(description="Webhook URL")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Get entities by rank (async)

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param hk: Webhook URL (required)
        :type hk: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get3_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            hk=hk,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get3_with_http_info(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        hk: Annotated[StrictStr, Field(description="Webhook URL")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Get entities by rank (async)

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param hk: Webhook URL (required)
        :type hk: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get3_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            hk=hk,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get3_without_preload_content(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        hk: Annotated[StrictStr, Field(description="Webhook URL")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get entities by rank (async)

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param hk: Webhook URL (required)
        :type hk: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get3_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            hk=hk,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get3_serialize(
        self,
        q,
        ln,
        lc,
        sd,
        hk,
        sc,
        d,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if ln is not None:
            
            _query_params.append(('ln', ln))
            
        if lc is not None:
            
            _query_params.append(('lc', lc))
            
        if sd is not None:
            
            _query_params.append(('sd', sd))
            
        if sc is not None:
            
            _query_params.append(('sc', sc))
            
        if hk is not None:
            
            _query_params.append(('hk', hk))
            
        if d is not None:
            
            _query_params.append(('d', d))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/longtail/hook',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def get_v2(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[RankEntities]:
        """Get entities by rank

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_v2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[RankEntities]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get_v2_with_http_info(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[RankEntities]]:
        """Get entities by rank

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_v2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[RankEntities]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get_v2_without_preload_content(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get entities by rank

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_v2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[RankEntities]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_v2_serialize(
        self,
        q,
        ln,
        lc,
        sd,
        sc,
        d,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if ln is not None:
            
            _query_params.append(('ln', ln))
            
        if lc is not None:
            
            _query_params.append(('lc', lc))
            
        if sd is not None:
            
            _query_params.append(('sd', sd))
            
        if sc is not None:
            
            _query_params.append(('sc', sc))
            
        if d is not None:
            
            _query_params.append(('d', d))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/longtail/v2',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


