# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.content_generations_api import ContentGenerationsApi


class TestContentGenerationsApi(unittest.TestCase):
    """ContentGenerationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContentGenerationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_content_generation(self) -> None:
        """Test case for create_content_generation

        Create
        """
        pass

    def test_delete_content_generation(self) -> None:
        """Test case for delete_content_generation

        Delete
        """
        pass

    def test_duplicate_content_generation(self) -> None:
        """Test case for duplicate_content_generation

        Duplicate
        """
        pass

    def test_get_content_generation(self) -> None:
        """Test case for get_content_generation

        Get
        """
        pass

    def test_list_content_generations(self) -> None:
        """Test case for list_content_generations

        List
        """
        pass

    def test_update_content_generation(self) -> None:
        """Test case for update_content_generation

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
