# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.submit_fact_check200_response import SubmitFactCheck200Response

class TestSubmitFactCheck200Response(unittest.TestCase):
    """SubmitFactCheck200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SubmitFactCheck200Response:
        """Test SubmitFactCheck200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SubmitFactCheck200Response`
        """
        model = SubmitFactCheck200Response()
        if include_optional:
            return SubmitFactCheck200Response(
                response = '{
  "@context": "http://schema.org",
  "@type": "ClaimReview",
  "claimReviewed": "Aristotle quote 'It is the mark of an educated mind to be able to entertain a thought without accepting it.'",
  "author": { "@type": "Organization", "name": "WordLift" },
  "datePublished": "2024-01-17",
  "reviewRating": {
    "@type": "Rating",
    "ratingValue": "5",
    "alternateName": "True",
    "bestRating": "5",
    "worstRating": "1"
  },
  "url": "https://fact-check.wordlift.io/review/aristotle-quote",
  "reviewBody": "The quote 'It is the mark of an educated mind to be able to entertain a thought without accepting it.' is correctly attributable to Aristotle. It has been found in multiple credible sources, including publications of academic texts, reputable quote repositories, and philosophical discussions.",
  "itemReviewed": {
    "@type": "CreativeWork",
    "url": ["https://www.azquotes.com/quote/10261", "https://philosiblog.com/2012/03/07/it-is-the-mark-of-an-educated-mind-to-be-able-to-entertain-a-thought-without-accepting-it/", "https://www.brainyquote.com/quotes/aristotle_100584", "https://www.goodreads.com/quotes/1629-it-is-the-mark-of-an-educated-mind-to-be", "https://www.socratic-method.com/philosophy-quote-meanings/aristotle-it-is-the-mark-of-an-educated-mind-to-be-able-to-entertain-a-thought-without-accepting-it"]
  }
}'
            )
        else:
            return SubmitFactCheck200Response(
        )
        """

    def testSubmitFactCheck200Response(self):
        """Test SubmitFactCheck200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
